@@ -45,6 +45,7 @@ from octohook.models import (
 
 
 class BaseWebhookEvent:
+    payload: dict
     action: Optional[str] = None
     sender: User
     repository: Optional[Repository] = None
@@ -52,6 +53,7 @@ class BaseWebhookEvent:
     enterprise: Optional[Enterprise] = None
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.action = payload.get("action")
         self.sender = User(payload.get("sender"))
 
@@ -650,10 +652,12 @@ class SecurityAdvisoryEvent:
     https://developer.github.com/v3/activity/events/types/#securityadvisoryevent
     """
 
+    payload: dict
     action: str
     security_advisory: SecurityAdvisory
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.action = payload.get("action")
         self.security_advisory = SecurityAdvisory(payload.get("security_advisory"))
 
