@@ -1,3 +1,4 @@
+from abc import ABC
 from typing import TypeVar, Optional, Type, List, Any
 
 T = TypeVar("T")
@@ -26,7 +27,16 @@ def _transform(url: str, local_variables: dict) -> str:
     return url
 
 
-class Enterprise:
+class BaseGithubModel(ABC):
+    def __new__(cls, *args, **kwargs):
+        from octohook import model_overrides
+
+        cls = model_overrides.get(cls) or cls
+        return object.__new__(cls)
+
+
+class Enterprise(BaseGithubModel):
+    payload: dict
     id: int
     slug: str
     name: str
@@ -39,6 +49,7 @@ class Enterprise:
     updated_at: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.slug = payload.get("slug")
         self.name = payload.get("name")
@@ -50,8 +61,12 @@ class Enterprise:
         self.created_at = payload.get("created_at")
         self.updated_at = payload.get("updated_at")
 
+    def __str__(self):
+        return self.name
 
-class User:
+
+class User(BaseGithubModel):
+    payload: dict
     name: Optional[str]
     login: str
     email: Optional[str]
@@ -71,7 +86,7 @@ class User:
     site_admin: bool
 
     def __init__(self, payload: dict):
-        self._payload = payload
+        self.payload = payload
         self.name = payload.get("name")
         self.login = payload.get("login")
         self.email = payload.get("email")
@@ -91,19 +106,23 @@ class User:
         self.site_admin = payload.get("site_admin")
 
     def following_url(self, other_user: str = None) -> str:
-        return _transform(self._payload["following_url"], locals())
+        return _transform(self.payload["following_url"], locals())
 
     def gists_url(self, gist_id: str = None) -> str:
-        return _transform(self._payload["gists_url"], locals())
+        return _transform(self.payload["gists_url"], locals())
 
     def starred_url(self, owner: str = None, repo: str = None) -> str:
-        return _transform(self._payload["starred_url"], locals())
+        return _transform(self.payload["starred_url"], locals())
 
     def events_url(self, privacy: str = None) -> str:
-        return _transform(self._payload["events_url"], locals())
+        return _transform(self.payload["events_url"], locals())
+
+    def __str__(self):
+        return self.login
 
 
-class ShortRepository:
+class ShortRepository(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     name: str
@@ -111,19 +130,24 @@ class ShortRepository:
     private: bool
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.name = payload.get("name")
         self.full_name = payload.get("full_name")
         self.private = payload.get("private")
 
+    def __str__(self):
+        return self.full_name
+
 
 class RawDict(dict):
     def __init__(self, payload: dict):
         super().__init__(payload)
 
 
-class Permissions:
+class Permissions(BaseGithubModel):
+    payload: dict
     metadata: str
     contents: str
     issues: str
@@ -148,6 +172,7 @@ class Permissions:
     team_discussions: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.metadata = payload.get("metadata")
         self.contents = payload.get("contents")
         self.issues = payload.get("issues")
@@ -172,7 +197,8 @@ class Permissions:
         self.team_discussions = payload.get("team_discussions")
 
 
-class Repository:
+class Repository(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     name: str
@@ -229,7 +255,7 @@ class Repository:
     permissions: Optional[Permissions]
 
     def __init__(self, payload: dict):
-        self._payload = payload
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.name = payload.get("name")
@@ -286,82 +312,86 @@ class Repository:
         self.permissions = _optional(payload, "permissions", Permissions)
 
     def keys_url(self, key_id: str = None) -> str:
-        return _transform(self._payload["keys_url"], locals())
+        return _transform(self.payload["keys_url"], locals())
 
     def collaborators_url(self, collaborator: str = None) -> str:
-        return _transform(self._payload["collaborators_url"], locals())
+        return _transform(self.payload["collaborators_url"], locals())
 
     def issue_events_url(self, number: int = None) -> str:
-        return _transform(self._payload["issue_events_url"], locals())
+        return _transform(self.payload["issue_events_url"], locals())
 
     def assignees_url(self, user: str = None) -> str:
-        return _transform(self._payload["assignees_url"], locals())
+        return _transform(self.payload["assignees_url"], locals())
 
     def branches_url(self, branch: str = None) -> str:
-        return _transform(self._payload["branches_url"], locals())
+        return _transform(self.payload["branches_url"], locals())
 
     def blobs_url(self, sha: str = None) -> str:
-        return _transform(self._payload["blobs_url"], locals())
+        return _transform(self.payload["blobs_url"], locals())
 
     def git_tags_url(self, sha: str = None) -> str:
-        return _transform(self._payload["git_tags_url"], locals())
+        return _transform(self.payload["git_tags_url"], locals())
 
     def git_refs_url(self, sha: str = None) -> str:
-        return _transform(self._payload["git_refs_url"], locals())
+        return _transform(self.payload["git_refs_url"], locals())
 
     def trees_url(self, sha: str = None) -> str:
-        return _transform(self._payload["trees_url"], locals())
+        return _transform(self.payload["trees_url"], locals())
 
     def statuses_url(self, sha: str) -> str:
-        return _transform(self._payload["statuses_url"], locals())
+        return _transform(self.payload["statuses_url"], locals())
 
     def commits_url(self, sha: str = None) -> str:
-        return _transform(self._payload["commits_url"], locals())
+        return _transform(self.payload["commits_url"], locals())
 
     def git_commits_url(self, sha=None) -> str:
-        return _transform(self._payload["git_commits_url"], locals())
+        return _transform(self.payload["git_commits_url"], locals())
 
     def comments_url(self, number: int = None) -> str:
-        return _transform(self._payload["comments_url"], locals())
+        return _transform(self.payload["comments_url"], locals())
 
     def issue_comment_url(self, number: int = None) -> str:
-        return _transform(self._payload["issue_comment_url"], locals())
+        return _transform(self.payload["issue_comment_url"], locals())
 
     def contents_url(self, path: str) -> str:
-        return _transform(self._payload["contents_url"].replace("+", ""), locals())
+        return _transform(self.payload["contents_url"].replace("+", ""), locals())
 
     def compare_url(self, base: str, head: str) -> str:
-        return _transform(self._payload["compare_url"], locals())
+        return _transform(self.payload["compare_url"], locals())
 
     def archive_url(self, archive_format: str, ref: str = None) -> str:
-        return _transform(self._payload["archive_url"], locals())
+        return _transform(self.payload["archive_url"], locals())
 
     def issues_url(self, number: str = None) -> str:
-        return _transform(self._payload["issues_url"], locals())
+        return _transform(self.payload["issues_url"], locals())
 
     def pulls_url(self, number: str = None) -> str:
-        return _transform(self._payload["pulls_url"], locals())
+        return _transform(self.payload["pulls_url"], locals())
 
     def milestones_url(self, number: str = None) -> str:
-        return _transform(self._payload["milestones_url"], locals())
+        return _transform(self.payload["milestones_url"], locals())
 
     def notifications_url(self, params: str = None) -> str:
         if params is not None:
             if not params.startswith("?"):
                 raise AttributeError("Params must be a query string starting with ?")
         replace_with = params if params else ""
-        return self._payload["notifications_url"].replace(
+        return self.payload["notifications_url"].replace(
             "{?since,all,participating}", replace_with
         )
 
     def labels_url(self, name: str = None) -> str:
-        return _transform(self._payload["labels_url"], locals())
+        return _transform(self.payload["labels_url"], locals())
 
     def releases_url(self, id: str = None) -> str:
-        return _transform(self._payload["releases_url"], locals())
+        return _transform(self.payload["releases_url"], locals())
+
+    def __str__(self):
+        return self.full_name
 
 
-class Organization:
+class Organization(BaseGithubModel):
+    payload: dict
     login: str
     id: int
     node_id: str
@@ -375,7 +405,7 @@ class Organization:
     description: str
 
     def __init__(self, payload: dict):
-        self._payload = payload
+        self.payload = payload
         self.login = payload.get("login")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -389,13 +419,17 @@ class Organization:
         self.description = payload.get("description")
 
     def members_url(self, member: str = None) -> str:
-        return _transform(self._payload["members_url"], locals())
+        return _transform(self.payload["members_url"], locals())
 
     def public_members_url(self, member: str = None) -> str:
-        return _transform(self._payload["public_members_url"], locals())
+        return _transform(self.payload["public_members_url"], locals())
+
+    def __str__(self):
+        return self.login
 
 
-class Comment:
+class Comment(BaseGithubModel):
+    payload: dict
     url: str
     html_url: str
     issue_url: Optional[str]
@@ -417,6 +451,7 @@ class Comment:
     body: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.html_url = payload.get("html_url")
         self.issue_url = payload.get("issue_url")
@@ -438,8 +473,12 @@ class Comment:
         self.body = payload.get("body")
         self._links = _optional(payload, "_links", RawDict)
 
+    def __str__(self):
+        return self.body
 
-class ChecksApp:
+
+class ChecksApp(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     owner: User
@@ -453,6 +492,7 @@ class ChecksApp:
     events: List[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.owner = User(payload.get("owner"))
@@ -466,7 +506,8 @@ class ChecksApp:
         self.events = payload.get("events")
 
 
-class ChecksPullRequest:
+class ChecksPullRequest(BaseGithubModel):
+    payload: dict
     url: str
     id: int
     number: int
@@ -474,6 +515,7 @@ class ChecksPullRequest:
     base: RawDict
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.number = payload.get("number")
@@ -481,18 +523,21 @@ class ChecksPullRequest:
         self.base = RawDict(payload.get("base"))
 
 
-class CommitUser:
+class CommitUser(BaseGithubModel):
+    payload: dict
     name: str
     email: str
     username: Optional[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.name = payload.get("name")
         self.email = payload.get("email")
         self.username = payload.get("username")
 
 
-class Commit:
+class Commit(BaseGithubModel):
+    payload: dict
     id: str
     tree_id: str
     distinct: bool
@@ -506,6 +551,7 @@ class Commit:
     modified: List[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.tree_id = payload.get("tree_id")
         self.distinct = payload.get("distinct")
@@ -519,7 +565,8 @@ class Commit:
         self.modified = payload.get("modified")
 
 
-class CheckSuite:
+class CheckSuite(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     head_branch: str
@@ -538,6 +585,7 @@ class CheckSuite:
     head_commit: Optional[Commit]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.head_branch = payload.get("head_branch")
@@ -558,7 +606,8 @@ class CheckSuite:
         self.head_commit = _optional(payload, "head_commit", Commit)
 
 
-class CheckRunOutput:
+class CheckRunOutput(BaseGithubModel):
+    payload: dict
     title: Optional[str]
     summary: Optional[str]
     text: Optional[str]
@@ -566,6 +615,7 @@ class CheckRunOutput:
     annotations_url: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.title = payload.get("title")
         self.summary = payload.get("summary")
         self.text = payload.get("text")
@@ -573,7 +623,8 @@ class CheckRunOutput:
         self.annotations_url = payload.get("annotations_url")
 
 
-class CheckRun:
+class CheckRun(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     head_sha: str
@@ -592,6 +643,7 @@ class CheckRun:
     pull_requests: List[ChecksPullRequest]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.head_sha = payload.get("head_sha")
@@ -612,16 +664,19 @@ class CheckRun:
         ]
 
 
-class ShortInstallation:
+class ShortInstallation(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
 
 
-class Installation:
+class Installation(BaseGithubModel):
+    payload: dict
     id: int
     node_id: Optional[str]
     account: User
@@ -639,6 +694,7 @@ class Installation:
     target_type: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id", None)
         self.account = _optional(payload, "account", User)
@@ -656,7 +712,8 @@ class Installation:
         self.target_type = payload.get("target_type")
 
 
-class DeployKey:
+class DeployKey(BaseGithubModel):
+    payload: dict
     id: int
     key: str
     url: str
@@ -666,6 +723,7 @@ class DeployKey:
     read_only: bool
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.key = payload.get("key")
         self.url = payload.get("url")
@@ -675,7 +733,8 @@ class DeployKey:
         self.read_only = payload.get("read_only")
 
 
-class Deployment:
+class Deployment(BaseGithubModel):
+    payload: dict
     url: str
     id: int
     node_id: str
@@ -693,6 +752,7 @@ class Deployment:
     repository_url: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -710,7 +770,8 @@ class Deployment:
         self.repository_url = payload.get("repository_url")
 
 
-class DeploymentStatus:
+class DeploymentStatus(BaseGithubModel):
+    payload: dict
     url: str
     id: int
     node_id: str
@@ -725,6 +786,7 @@ class DeploymentStatus:
     repository_url: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -739,7 +801,8 @@ class DeploymentStatus:
         self.repository_url = payload.get("repository_url")
 
 
-class Page:
+class Page(BaseGithubModel):
+    payload: dict
     page_name: str
     title: str
     summary: str
@@ -748,6 +811,7 @@ class Page:
     html_url: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.page_name = payload.get("page_name")
         self.title = payload.get("title")
         self.summary = payload.get("summary")
@@ -756,7 +820,8 @@ class Page:
         self.html_url = payload.get("html_url")
 
 
-class Label:
+class Label(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     url: str
@@ -766,6 +831,7 @@ class Label:
     default: bool
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.url = payload.get("url")
@@ -774,8 +840,18 @@ class Label:
         self.description = payload.get("description")
         self.default = payload.get("default")
 
+    def __eq__(self, other):
+        return self.name == other
 
-class Milestone:
+    def __repr__(self):
+        return f"{self.name}(#{self.color})"
+
+    def __str__(self):
+        return self.name
+
+
+class Milestone(BaseGithubModel):
+    payload: dict
     url: str
     html_url: str
     labels_url: str
@@ -794,6 +870,7 @@ class Milestone:
     closed_at: Optional[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.html_url = payload.get("html_url")
         self.labels_url = payload.get("labels_url")
@@ -812,7 +889,8 @@ class Milestone:
         self.closed_at = payload.get("closed_at")
 
 
-class Issue:
+class Issue(BaseGithubModel):
+    payload: dict
     url: str
     repository_url: str
     comments_url: str
@@ -837,7 +915,7 @@ class Issue:
     body: str
 
     def __init__(self, payload: dict):
-        self._payload = payload
+        self.payload = payload
         self.url = payload.get("url")
         self.repository_url = payload.get("repository_url")
         self.comments_url = payload.get("comments_url")
@@ -862,23 +940,26 @@ class Issue:
         self.body = payload.get("body")
 
     def labels_url(self, name: str = None) -> str:
-        return _transform(self._payload["labels_url"], locals())
+        return _transform(self.payload["labels_url"], locals())
 
 
-class PurchaseAccount:
+class PurchaseAccount(BaseGithubModel):
+    payload: dict
     type: str
     id: int
     login: str
     organization_billing_email: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.type = payload.get("type")
         self.id = payload.get("id")
         self.login = payload.get("login")
         self.organization_billing_email = payload.get("organization_billing_email")
 
 
-class Plan:
+class Plan(BaseGithubModel):
+    payload: dict
     id: int
     name: str
     description: str
@@ -891,6 +972,7 @@ class Plan:
     bullets: List[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.name = payload.get("name")
         self.description = payload.get("description")
@@ -903,7 +985,8 @@ class Plan:
         self.bullets = payload.get("bullets")
 
 
-class MarketplacePurchase:
+class MarketplacePurchase(BaseGithubModel):
+    payload: dict
     account: PurchaseAccount
     billing_cycle: str
     unit_count: int
@@ -913,6 +996,7 @@ class MarketplacePurchase:
     plan: Plan
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.account = PurchaseAccount(payload.get("account"))
         self.billing_cycle = payload.get("billing_cycle")
         self.unit_count = payload.get("unit_count")
@@ -922,7 +1006,8 @@ class MarketplacePurchase:
         self.plan = Plan(payload.get("plan"))
 
 
-class Team:
+class Team(BaseGithubModel):
+    payload: dict
     name: str
     id: int
     node_id: str
@@ -935,7 +1020,7 @@ class Team:
     permission: str
 
     def __init__(self, payload: dict):
-        self._payload = payload
+        self.payload = payload
         self.name = payload.get("name")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -948,10 +1033,11 @@ class Team:
         self.permission = payload.get("permission")
 
     def members_url(self, member: str = None) -> str:
-        return _transform(self._payload["members_url"], locals())
+        return _transform(self.payload["members_url"], locals())
 
 
-class Hook:
+class Hook(BaseGithubModel):
+    payload: dict
     type: str
     id: int
     name: str
@@ -962,6 +1048,7 @@ class Hook:
     created_at: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.type = payload.get("type")
         self.id = payload.get("id")
         self.name = payload.get("name")
@@ -972,7 +1059,8 @@ class Hook:
         self.created_at = payload.get("created_at")
 
 
-class Membership:
+class Membership(BaseGithubModel):
+    payload: dict
     url: str
     state: str
     role: str
@@ -980,6 +1068,7 @@ class Membership:
     user: User
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.state = payload.get("state")
         self.role = payload.get("role")
@@ -987,7 +1076,8 @@ class Membership:
         self.user = User(payload.get("user"))
 
 
-class Asset:
+class Asset(BaseGithubModel):
+    payload: dict
     url: str
     id: str
     node_id: str
@@ -1003,6 +1093,7 @@ class Asset:
     browser_download_url: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -1018,7 +1109,8 @@ class Asset:
         self.browser_download_url = payload.get("browser_download_url")
 
 
-class Release:
+class Release(BaseGithubModel):
+    payload: dict
     url: str
     assets_url: Optional[str]
     upload_url: Optional[str]
@@ -1039,6 +1131,7 @@ class Release:
     body: Optional[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.assets_url = payload.get("assets_url", None)
         self.upload_url = payload.get("upload_url", None)
@@ -1059,7 +1152,8 @@ class Release:
         self.body = payload.get("body", None)
 
 
-class PackageFile:
+class PackageFile(BaseGithubModel):
+    payload: dict
     download_url: str
     id: str
     name: str
@@ -1073,6 +1167,7 @@ class PackageFile:
     updated_at: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.download_url = payload.get("download_url")
         self.id = payload.get("id")
         self.name = payload.get("name")
@@ -1086,7 +1181,8 @@ class PackageFile:
         self.updated_at = payload.get("updated_at")
 
 
-class PackageVersion:
+class PackageVersion(BaseGithubModel):
+    payload: dict
     id: int
     version: str
     summary: str
@@ -1108,6 +1204,7 @@ class PackageVersion:
     installation_command: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.version = payload.get("version")
         self.summary = payload.get("summary")
@@ -1131,7 +1228,8 @@ class PackageVersion:
         self.installation_command = payload.get("installation_command")
 
 
-class Registry:
+class Registry(BaseGithubModel):
+    payload: dict
     about_url: str
     name: str
     type: str
@@ -1139,6 +1237,7 @@ class Registry:
     vendor: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.about_url = payload.get("about_url")
         self.name = payload.get("name")
         self.type = payload.get("type")
@@ -1146,7 +1245,8 @@ class Registry:
         self.vendor = payload.get("vendor")
 
 
-class Package:
+class Package(BaseGithubModel):
+    payload: dict
     id: int
     name: str
     package_type: str
@@ -1158,6 +1258,7 @@ class Package:
     registry: Registry
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.name = payload.get("name")
         self.package_type = payload.get("package_type")
@@ -1169,7 +1270,8 @@ class Package:
         self.registry = Registry(payload.get("registry"))
 
 
-class PageBuild:
+class PageBuild(BaseGithubModel):
+    payload: dict
     url: str
     status: str
     error: RawDict
@@ -1180,6 +1282,7 @@ class PageBuild:
     updated_at: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.status = payload.get("status")
         self.error = RawDict(payload.get("error"))
@@ -1190,7 +1293,8 @@ class PageBuild:
         self.updated_at = payload.get("updated_at")
 
 
-class ProjectCard:
+class ProjectCard(BaseGithubModel):
+    payload: dict
     url: str
     project_url: str
     column_url: str
@@ -1206,6 +1310,7 @@ class ProjectCard:
     content_url: Optional[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.project_url = payload.get("project_url")
         self.column_url = payload.get("column_url")
@@ -1221,7 +1326,8 @@ class ProjectCard:
         self.content_url = payload.get("content_url")
 
 
-class ProjectColumn:
+class ProjectColumn(BaseGithubModel):
+    payload: dict
     url: str
     project_url: str
     cards_url: str
@@ -1233,6 +1339,7 @@ class ProjectColumn:
     after_id: Optional[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
         self.project_url = payload.get("project_url")
         self.cards_url = payload.get("cards_url")
@@ -1244,7 +1351,8 @@ class ProjectColumn:
         self.after_id = payload.get("after_id")
 
 
-class Project:
+class Project(BaseGithubModel):
+    payload: dict
     owner_url: str
     url: str
     html_url: str
@@ -1260,6 +1368,7 @@ class Project:
     updated_at: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.owner_url = payload.get("owner_url")
         self.url = payload.get("url")
         self.html_url = payload.get("html_url")
@@ -1275,7 +1384,8 @@ class Project:
         self.updated_at = payload.get("updated_at")
 
 
-class Ref:
+class Ref(BaseGithubModel):
+    payload: dict
     label: str
     ref: str
     sha: str
@@ -1283,6 +1393,7 @@ class Ref:
     repo: Repository
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.label = payload.get("label")
         self.ref = payload.get("ref")
         self.sha = payload.get("sha")
@@ -1290,7 +1401,8 @@ class Ref:
         self.repo = Repository(payload.get("repo"))
 
 
-class PullRequest:
+class PullRequest(BaseGithubModel):
+    payload: dict
     url: str
     id: int
     node_id: str
@@ -1338,7 +1450,7 @@ class PullRequest:
     changed_files: Optional[int]
 
     def __init__(self, payload: dict):
-        self._payload = payload
+        self.payload = payload
         self.url = payload.get("url")
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
@@ -1388,10 +1500,14 @@ class PullRequest:
         self.changed_files = payload.get("changed_files")
 
     def review_comment_url(self, number: int = None) -> str:
-        return _transform(self._payload["review_comment_url"], locals())
+        return _transform(self.payload["review_comment_url"], locals())
+
+    def __str__(self):
+        return f"#{self.number} {self.title}"
 
 
-class Review:
+class Review(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     user: User
@@ -1405,6 +1521,7 @@ class Review:
     _links: RawDict
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.user = User(payload.get("user"))
@@ -1418,7 +1535,8 @@ class Review:
         self._links = RawDict(payload.get("_links"))
 
 
-class VulnerabilityAlert:
+class VulnerabilityAlert(BaseGithubModel):
+    payload: dict
     id: int
     affected_range: str
     affected_package_name: str
@@ -1427,6 +1545,7 @@ class VulnerabilityAlert:
     fixed_in: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.affected_range = payload.get("affected_range")
         self.affected_package_name = payload.get("affected_package_name")
@@ -1435,29 +1554,35 @@ class VulnerabilityAlert:
         self.fixed_in = payload.get("fixed_in")
 
 
-class VulnerablePackage:
+class VulnerablePackage(BaseGithubModel):
+    payload: dict
     ecosystem: str
     name: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.ecosystem = payload.get("ecosystem")
         self.name = payload.get("name")
 
 
-class PackageVersionInfo:
+class PackageVersionInfo(BaseGithubModel):
+    payload: dict
     identifier: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.identifier = payload.get("identifier")
 
 
-class Vulnerability:
+class Vulnerability(BaseGithubModel):
+    payload: dict
     package: VulnerablePackage
     severity: str
     vulnerable_version_range: str
     first_patched_version: PackageVersionInfo
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.package = VulnerablePackage(payload.get("package"))
         self.severity = payload.get("severity")
         self.vulnerable_version_range = payload.get("vulnerable_version_range")
@@ -1466,23 +1591,28 @@ class Vulnerability:
         )
 
 
-class SecurityVulnerabilityIdentifier:
+class SecurityVulnerabilityIdentifier(BaseGithubModel):
+    payload: dict
     value: str
     type: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.value: str = payload.get("value")
         self.type: str = payload.get("type")
 
 
-class SecurityAdvisoryReference:
+class SecurityAdvisoryReference(BaseGithubModel):
+    payload: dict
     url: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.url = payload.get("url")
 
 
-class SecurityAdvisory:
+class SecurityAdvisory(BaseGithubModel):
+    payload: dict
     ghsa_id: str
     summary: str
     description: str
@@ -1495,6 +1625,7 @@ class SecurityAdvisory:
     vulnerabilities: List[Vulnerability]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.ghsa_id = payload.get("ghsa_id")
         self.summary = payload.get("summary")
         self.description = payload.get("description")
@@ -1515,7 +1646,8 @@ class SecurityAdvisory:
         ]
 
 
-class SponsorshipTier:
+class SponsorshipTier(BaseGithubModel):
+    payload: dict
     node_id: str
     created_at: str
     description: str
@@ -1524,6 +1656,7 @@ class SponsorshipTier:
     name: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.node_id = payload.get("node_id")
         self.created_at = payload.get("created_at")
         self.description = payload.get("description")
@@ -1532,7 +1665,8 @@ class SponsorshipTier:
         self.name = payload.get("name")
 
 
-class Sponsorship:
+class Sponsorship(BaseGithubModel):
+    payload: dict
     node_id: str
     created_at: str
     maintainer: User
@@ -1541,6 +1675,7 @@ class Sponsorship:
     tier: SponsorshipTier
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.node_id = payload.get("node_id")
         self.created_at = payload.get("created_at")
         self.maintainer = User(payload.get("maintainer"))
@@ -1549,53 +1684,62 @@ class Sponsorship:
         self.tier = SponsorshipTier(payload.get("tier"))
 
 
-class StatusBranchCommit:
+class StatusBranchCommit(BaseGithubModel):
+    payload: dict
     sha: str
     url: str
     html_url: Optional[str]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.sha = payload.get("sha")
         self.url = payload.get("url")
         self.html_url = payload.get("html_url", None)
 
 
-class Branch:
+class Branch(BaseGithubModel):
+    payload: dict
     name: str
     commit: StatusBranchCommit
     protected: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.name = payload.get("name")
         self.commit = StatusBranchCommit(payload.get("commit"))
         self.protected = payload.get("protected")
 
 
-class StatusCommitVerification:
+class StatusCommitVerification(BaseGithubModel):
+    payload: dict
     verified: bool
     reason: str
     signature: str
     payload: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.verified = payload.get("verified")
         self.reason = payload.get("reason")
         self.signature = payload.get("signature")
         self.payload = payload.get("payload")
 
 
-class StatusNestedCommitUser:
+class StatusNestedCommitUser(BaseGithubModel):
+    payload: dict
     name: str
     email: str
     date: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.name = payload.get("name")
         self.email = payload.get("email")
         self.date = payload.get("date")
 
 
-class StatusNestedCommit:
+class StatusNestedCommit(BaseGithubModel):
+    payload: dict
     author: StatusNestedCommitUser
     committer: StatusNestedCommitUser
     message: str
@@ -1605,6 +1749,7 @@ class StatusNestedCommit:
     verification: StatusCommitVerification
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.author = StatusNestedCommitUser(payload.get("author"))
         self.committer = StatusNestedCommitUser(payload.get("committer"))
         self.message = payload.get("message")
@@ -1614,7 +1759,8 @@ class StatusNestedCommit:
         self.verification = StatusCommitVerification(payload.get("verification"))
 
 
-class StatusCommit:
+class StatusCommit(BaseGithubModel):
+    payload: dict
     sha: str
     node_id: str
     commit: StatusNestedCommit
@@ -1626,6 +1772,7 @@ class StatusCommit:
     parents: List[StatusBranchCommit]
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.sha = payload.get("sha")
         self.node_id = payload.get("node_id")
         self.commit = StatusNestedCommit(payload.get("commit"))
@@ -1637,12 +1784,14 @@ class StatusCommit:
         self.parents = [StatusBranchCommit(parent) for parent in payload.get("parents")]
 
 
-class ContentReference:
+class ContentReference(BaseGithubModel):
+    payload: dict
     id: int
     node_id: str
     reference: str
 
     def __init__(self, payload: dict):
+        self.payload = payload
         self.id = payload.get("id")
         self.node_id = payload.get("node_id")
         self.reference = payload.get("reference")
